@@ -9,17 +9,28 @@ import os
 import re
 import shutil
 import sys
+import tempfile
 from collections import OrderedDict, namedtuple
 from contextlib import suppress
 from locale import localeconv
-from threading import Lock
+from threading import RLock
 
 from calibre import as_unicode, prints
 from calibre.constants import cache_dir, get_windows_number_formats, iswindows, preferred_encoding
+from calibre.utils.filenames import make_long_path_useable
 from calibre.utils.icu import lower as icu_lower
 from calibre.utils.localization import canonicalize_lang, ngettext
 
 
+def atomic_write(path: str, data: str | bytes) -> None:
+    mode = 'w' if isinstance(data, str) else 'wb'
+    dpath = make_long_path_useable(os.path.dirname(path))
+    os.makedirs(dpath, exist_ok=True)
+    with tempfile.NamedTemporaryFile(mode, delete=False, dir=dpath) as f:
+        f.write(data)
+    os.replace(make_long_path_useable(f.name), make_long_path_useable(path))
+
+
 def force_to_bool(val):
     if isinstance(val, (bytes, str)):
         if isinstance(val, bytes):
@@ -109,14 +120,14 @@ class ThumbnailCache:
     ' This is a persistent disk cache to speed up loading and resizing of covers '
 
     def __init__(self,
-                 max_size=1024,  # The maximum disk space in MB
-                 name='thumbnail-cache',  # The name of this cache (should be unique in location)
-                 thumbnail_size=(100, 100),   # The size of the thumbnails, can be changed
-                 location=None,   # The location for this cache, if None cache_dir() is used
-                 test_mode=False,  # Used for testing
-                 min_disk_cache=0,  # If the size is set less than or equal to this value, the cache is disabled.
-                 version=0  # Increase this if the cache content format might have changed.
-                 ):
+        max_size=1024,  # The maximum disk space in MB
+        name='thumbnail-cache',  # The name of this cache (should be unique in location)
+        thumbnail_size=(100, 100),   # The size of the thumbnails, can be changed
+        location=None,   # The location for this cache, if None cache_dir() is used
+        test_mode=False,  # Used for testing
+        min_disk_cache=0,  # If the size is set less than or equal to this value, the cache is disabled.
+        version=0  # Increase this if the cache content format might have changed.
+    ):
         self.version = version
         self.location = os.path.join(location or cache_dir(), name)
         if max_size <= min_disk_cache:
@@ -125,7 +136,7 @@ class ThumbnailCache:
         self.group_id = 'group'
         self.thumbnail_size = thumbnail_size
         self.size_changed = False
-        self.lock = Lock()
+        self.lock = RLock()
         self.min_disk_cache = min_disk_cache
         if test_mode:
             self.log = self.fail_on_error
@@ -247,15 +258,6 @@ class ThumbnailCache:
             self._do_delete(entry.path)
             self.total_size -= entry.size
 
-    def _write_order(self):
-        if hasattr(self, 'items'):
-            try:
-                data = '\n'.join(group_id + ' ' + str(book_id) for (group_id, book_id) in self.items)
-                with open(os.path.join(self.location, 'order'), 'wb') as f:
-                    f.write(data.encode('utf-8'))
-            except OSError as err:
-                self.log('Failed to save thumbnail cache order:', as_unicode(err))
-
     def _read_order(self):
         order = {}
         try:
@@ -271,7 +273,14 @@ class ThumbnailCache:
 
     def shutdown(self):
         with self.lock:
-            self._write_order()
+            if (items := getattr(self, 'items', None)) is not None:
+                del self.items
+                try:
+                    data = '\n'.join(group_id + ' ' + str(book_id) for (group_id, book_id) in items)
+                    with open(os.path.join(self.location, 'order'), 'wb') as f:
+                        f.write(data.encode('utf-8'))
+                except OSError as err:
+                    self.log('Failed to save thumbnail cache order:', as_unicode(err))
 
     def set_group_id(self, group_id):
         with self.lock:
@@ -401,10 +410,12 @@ class ThumbnailCache:
         if size_in_mb <= self.min_disk_cache:
             size_in_mb = 0
         size_in_mb = max(0, size_in_mb)
+        new_size = int(size_in_mb * (1024**2))
         with self.lock:
-            self.max_size = int(size_in_mb * (1024**2))
-            if hasattr(self, 'total_size'):
-                self._apply_size()
+            if new_size != self.max_size:
+                self.max_size = new_size
+                if hasattr(self, 'total_size'):
+                    self._apply_size()
 
 
 number_separators = None
