@@ -341,7 +341,7 @@ class View:
             return restriction
 
     def search_getting_ids(self, query, search_restriction,
-                           set_restriction_count=False, use_virtual_library=True, sort_results=True):
+                           set_restriction_count=False, use_virtual_library=True, sort_results=True, allow_templates=True):
         if use_virtual_library:
             search_restriction = self._build_restriction_string(search_restriction)
         q = ''
@@ -361,8 +361,10 @@ class View:
                 self.full_map_is_sorted = True
             return rv
         matches = self.cache.search(
-            query, search_restriction, virtual_fields={'marked':MarkedVirtualField(self.marked_ids),
-                                           'in_tag_browser': InTagBrowserVirtualField(self.tag_browser_ids)})
+            query, search_restriction, virtual_fields={
+                'marked':MarkedVirtualField(self.marked_ids),
+                'in_tag_browser': InTagBrowserVirtualField(self.tag_browser_ids)
+            }, allow_templates=allow_templates)
         if len(matches) == len(self._map):
             rv = list(self._map)
         else:
