@@ -9,11 +9,11 @@ import time
 import traceback
 
 import apsw
-from qt.core import QCoreApplication, QIcon, QObject, QTimer
+from qt.core import QCoreApplication, QIcon, QObject, QTimer, sip
 
-from calibre import force_unicode, prints
+from calibre import force_unicode, prints, timed_print
 from calibre.constants import DEBUG, MAIN_APP_UID, __appname__, filesystem_encoding, get_portable_base, islinux, ismacos, iswindows
-from calibre.gui2 import Application, choose_dir, error_dialog, gprefs, initialize_file_icon_provider, question_dialog, setup_gui_option_parser, timed_print
+from calibre.gui2 import Application, choose_dir, error_dialog, gprefs, initialize_file_icon_provider, question_dialog, setup_gui_option_parser
 from calibre.gui2.listener import send_message_in_process
 from calibre.gui2.main_window import option_parser as _option_parser
 from calibre.gui2.splash_screen import SplashScreen
@@ -436,6 +436,10 @@ def run_gui_(opts, args, app, gui_debug=None):
                 f.truncate()
                 f.write(raw)
         open_local_file(debugfile)
+    if runner.main:
+        sip.delete(runner.main)
+        runner.main = None
+    del runner
     return ret
 
 
@@ -551,6 +555,10 @@ def main(args=sys.argv):
             run_main(app, opts, args, gui_debug, si, retry_communicate=False)
     if after_quit_actions['restart_after_quit']:
         restart_after_quit()
+    sip.delete(app)
+    del app
+    import gc
+    gc.collect(), gc.collect()
 
 
 def run_main(app, opts, args, gui_debug, si, retry_communicate=False):
