@@ -31,7 +31,7 @@ from qt.core import (
     QWidget,
 )
 
-from calibre.gui2 import error_dialog
+from calibre.gui2 import error_dialog, question_dialog
 from calibre.gui2.dialogs.template_dialog import TemplateDialog
 from calibre.gui2.dialogs.template_line_editor import TemplateLineEditor
 from calibre.utils.date import UNDEFINED_DATE, parse_date
@@ -476,15 +476,16 @@ class CreateCustomColumn(QDialog):
             'If checked, this column will be displayed as HTML in '
             'Book details and the Content server. This can be used to '
             'construct links with the template language. For example, '
-            'the template '
-            '<pre>&lt;big&gt;&lt;b&gt;{title}&lt;/b&gt;&lt;/big&gt;'
-            '{series:| [|}{series_index:| [|]]}</pre>'
+            'the template {0} '
             'will create a field displaying the title in bold large '
             'characters, along with the series, for example <br>"<big><b>'
-            'An Oblique Approach</b></big> [Belisarius [1]]". The template '
-            '<pre>&lt;a href="https://www.beam-ebooks.de/ebook/{identifiers'
-            ':select(beam)}"&gt;Beam book&lt;/a&gt;</pre> '
-            'will generate a link to the book on the Beam e-books site.') + '</p>')
+            'An Oblique Approach</b></big> [Belisarius [1]]". The template {1} '
+            'will generate a link to the book on the Beam e-books site.').format(
+                '<pre>&lt;big&gt;&lt;b&gt;{title}&lt;/b&gt;&lt;/big&gt;'
+                '{series:| [|}{series_index:| [|]]}</pre>',
+                '<pre>&lt;a href="https://www.beam-ebooks.de/ebook/{identifiers'
+                ':select(beam)}"&gt;Beam book&lt;/a&gt;</pre> '
+        ) + '</p>')
         l.addWidget(cch)
         l.addStretch()
         add_row(None, l)
@@ -653,7 +654,7 @@ class CreateCustomColumn(QDialog):
             else:
                 l, dl = _('&Format for numbers:'), (
                     '<p>' + _('Default: Not formatted. For format language details see'
-                    ' <a href="https://docs.python.org/library/string.html#format-string-syntax">the Python documentation</a>'))
+                    ' <a href="{}">the Python documentation</a>').format('https://docs.python.org/library/string.html#format-string-syntax'))
                 if col_type == 'int':
                     self.format_box.setToolTip('<p>' + _(
                         'Examples: The format <code>{0:0>4d}</code> '
@@ -738,7 +739,13 @@ class CreateCustomColumn(QDialog):
             if self.standard_colheads[t] == col_heading:
                 bad_head = True
         if bad_head:
-            return self.simple_error('', _('The heading %s is already used')%col_heading)
+            if not question_dialog(self, _('Are you sure?'),
+                _('The heading {} is already used by another column.'
+                ' Creating a second column with the same heading can be confusing.'
+                ' Are you sure?').format(col_heading),
+                skip_dialog_name='create_custom_column_shared_heading',
+                default_yes=False, override_icon='dialog_warning.png'):
+                return
 
         display_dict = {}
 
