@@ -31,6 +31,7 @@ def debug(*a, **kw):
         if not hasattr(debug, 'first'):
             debug.first = monotonic()
         kw['end'] = kw.get('end', '\r\n')
+        kw['flush'] = True
         print(f'[{monotonic() - debug.first:.2f}]', *a, **kw)
 
 
@@ -284,6 +285,8 @@ class Piper(TTSBackend):
             if gp is not None:
                 gp.cancel()
             self._audio_sink.stateChanged.disconnect()
+            with suppress(TypeError):
+                self._utterances_being_spoken.readyRead.disconnect()
             # this dance is needed otherwise stop() is very slow on Linux
             self._audio_sink.suspend()
             self._audio_sink.reset()
@@ -293,6 +296,7 @@ class Piper(TTSBackend):
             self._utterances_being_synthesized.clear()
             self._utterances_being_spoken.clear()
             self._set_state(QTextToSpeech.State.Ready)
+            debug('Audio sink has been shutdown')
 
     def reload_after_configure(self) -> None:
         self.shutdown()
@@ -581,9 +585,8 @@ def develop():
                 debug('Quitting on completion')
                 app.quit()
 
-    def input_ready():
+    def handle_input(q: bytes):
         nonlocal play_started
-        q = sys.stdin.buffer.read()
         if q in (b'\x03', b'\x1b'):
             app.exit(1)
         elif q == b' ':
@@ -609,12 +612,25 @@ def develop():
 
     p.state_changed.connect(state_changed)
     p.saying.connect(saying)
-    if not iswindows:
+    if iswindows:
+        from threading import Thread
+        current_input = b''
+        class Dispatcher(QObject):
+            dispatch = pyqtSignal(object)
+        o = Dispatcher(app)
+        o.dispatch.connect(handle_input)
+        def poll_input():
+            nonlocal current_input
+            import msvcrt
+            while True:
+                o.dispatch.emit(msvcrt.getch())
+        Thread(target=poll_input, daemon=True).start()
+    else:
         import tty
         attr = tty.setraw(sys.stdin.fileno())
         os.set_blocking(sys.stdin.fileno(), False)
-    sn = QSocketNotifier(sys.stdin.fileno(), QSocketNotifier.Type.Read, p)
-    sn.activated.connect(input_ready)
+        sn = QSocketNotifier(sys.stdin.fileno(), QSocketNotifier.Type.Read, p)
+        sn.activated.connect(lambda: handle_input(sys.stdin.buffer.read()))
     try:
         p.say(text)
         app.exec()
