@@ -10,10 +10,11 @@ from concurrent.futures import ThreadPoolExecutor
 from datetime import datetime
 from functools import partial
 from itertools import count
+from urllib.parse import urlparse
 
 from lxml.etree import Comment
 
-from calibre import detect_ncpus, prepare_string_for_xml
+from calibre import prepare_string_for_xml
 from calibre.customize.ui import plugin_for_input_format
 from calibre.ebooks.oeb.base import EPUB, OEB_DOCS, OEB_STYLES, OPF, SMIL, XHTML, XHTML_NS, XLINK, rewrite_links, urlunquote
 from calibre.ebooks.oeb.base import XPath as _XPath
@@ -22,6 +23,7 @@ from calibre.ebooks.oeb.polish.container import Container as ContainerBase
 from calibre.ebooks.oeb.polish.cover import find_cover_image, find_cover_image_in_page, find_cover_page
 from calibre.ebooks.oeb.polish.toc import from_xpaths, get_landmarks, get_toc
 from calibre.ebooks.oeb.polish.utils import guess_type
+from calibre.library.page_count import calculate_number_of_workers, get_length
 from calibre.srv.metadata import encode_datetime
 from calibre.utils.date import EPOCH
 from calibre.utils.forked_map import forked_map, forked_map_is_supported
@@ -33,13 +35,7 @@ from polyglot.binary import as_base64_unicode as encode_component
 from polyglot.binary import from_base64_bytes
 from polyglot.binary import from_base64_unicode as decode_component
 from polyglot.builtins import as_bytes
-from polyglot.urllib import urlparse
 
-try:
-    from calibre_extensions.speedup import get_num_of_significant_chars
-except ImportError:  # running from source without updated binary
-    def get_num_of_significant_chars(elem):
-        return len(getattr(elem, 'text', '') or '') + len(getattr(elem, 'tail', '') or '')
 RENDER_VERSION = 1
 
 BLANK_JPEG = b'\xff\xd8\xff\xdb\x00C\x00\x03\x02\x02\x02\x02\x02\x03\x02\x02\x02\x03\x03\x03\x03\x04\x06\x04\x04\x04\x04\x04\x08\x06\x06\x05\x06\t\x08\n\n\t\x08\t\t\n\x0c\x0f\x0c\n\x0b\x0e\x0b\t\t\r\x11\r\x0e\x0f\x10\x10\x11\x10\n\x0c\x12\x13\x12\x10\x13\x0f\x10\x10\x10\xff\xc9\x00\x0b\x08\x00\x01\x00\x01\x01\x01\x11\x00\xff\xcc\x00\x06\x00\x10\x10\x05\xff\xda\x00\x08\x01\x01\x00\x00?\x00\xd2\xcf \xff\xd9'  # noqa: E501
@@ -137,15 +133,6 @@ def anchor_map(root):
     return ans
 
 
-def get_length(root):
-    ans = 0
-    for body in root.iterchildren(XHTML('body')):
-        ans += get_num_of_significant_chars(body)
-        for elem in body.iterdescendants():
-            ans += get_num_of_significant_chars(elem)
-    return ans
-
-
 def toc_anchor_map(toc):
     ans = defaultdict(list)
     seen_map = defaultdict(set)
@@ -566,16 +553,6 @@ def process_book_file(virtualize_resources, link_uid, container, present_names,
     return link_to_map, html_data, virtualized_names, smil_map
 
 
-def calculate_number_of_workers(names, in_process_container, max_workers):
-    num_workers = min(detect_ncpus(), len(names))
-    if max_workers:
-        num_workers = min(num_workers, max_workers)
-    if num_workers > 1:
-        if len(names) < 3 or sum(os.path.getsize(in_process_container.name_path_map[n]) for n in names) < 128 * 1024:
-            num_workers = 1
-    return num_workers
-
-
 def process_exploded_book(
     book_fmt, opfpath, input_fmt, tdir, log=None, book_hash=None, save_bookmark_data=False,
     book_metadata=None, virtualize_resources=True, max_workers=1
