@@ -437,6 +437,8 @@ def run_rapydscript_tests():
 
 def set_data(src, **kw):
     from calibre.db.constants import NO_SEARCH_LINK
+    from calibre.ebooks.oeb.polish.main import SUPPORTED
+    from calibre.library.page_count import CHARS_PER_PAGE
     for k, v in {
         '__SPECIAL_TITLE__': SPECIAL_TITLE_FOR_WEBENGINE_COMMS,
         '__FAKE_PROTOCOL__': FAKE_PROTOCOL,
@@ -447,6 +449,8 @@ def set_data(src, **kw):
         '__BUILTIN_COLORS_DARK__': json.dumps(builtin_colors_dark),
         '__BUILTIN_DECORATIONS__': json.dumps(builtin_decorations),
         '__NO_SEARCH_LINK__': NO_SEARCH_LINK,
+        '__CHARS_PER_PAGE__': str(CHARS_PER_PAGE),
+        '__EDITABLE_FORMATS__': json.dumps(tuple(SUPPORTED)),
     }.items():
         src = src.replace(k, v, 1)
     for k, v in kw.items():
@@ -515,24 +519,45 @@ def compile_srv():
 # Translations {{{
 
 def create_pot(source_files):
-    c = compiler()
-    gettext_options = json.dumps({
+    global has_external_compiler
+    if has_external_compiler is None:
+        has_external_compiler = detect_external_compiler()
+    gettext_options = {
         'package_name': __appname__,
         'package_version': __version__,
         'bugs_address': 'https://bugs.launchpad.net/calibre'
-    })
-    c.eval(f'window.catalog = {{}}; window.gettext_options = {gettext_options}; 1')
-    for fname in source_files:
-        with open(fname, 'rb') as f:
-            code = f.read().decode('utf-8')
-        c.eval('RapydScript.gettext_parse(window.catalog, {}, {}); 1'.format(*map(json.dumps, (code, fname))))
+    }
+    if not has_external_compiler:
+        c = compiler()
+        c.eval(f'window.catalog = {{}}; window.gettext_options = {json.dumps(gettext_options)}; 1')
+        for fname in source_files:
+            with open(fname, 'rb') as f:
+                code = f.read().decode('utf-8')
+            c.eval('RapydScript.gettext_parse(window.catalog, {}, {}); 1'.format(*map(json.dumps, (code, fname))))
 
-    buf = c.eval('ans = []; RapydScript.gettext_output(window.catalog, window.gettext_options, ans.push.bind(ans)); ans;')
-    return ''.join(buf)
+        buf = c.eval('ans = []; RapydScript.gettext_output(window.catalog, window.gettext_options, ans.push.bind(ans)); ans;')
+        return ''.join(buf)
+    cp = subprocess.run([
+        has_external_compiler, 'gettext', '--package-name', gettext_options['package_name'],
+        '--package-version', gettext_options['package_version'], '--bugs-address', gettext_options['bugs_address'],
+    ] + list(source_files), capture_output=True)
+    if cp.returncode != 0:
+        sys.stderr.buffer.write(cp.stderr)
+        raise SystemExit(cp.returncode)
+    return cp.stdout.decode().strip()
 
 
 def msgfmt(po_data_as_string):
-    c = compiler()
-    return c.eval('RapydScript.msgfmt({}, {})'.format(
-        json.dumps(po_data_as_string), json.dumps({'use_fuzzy': False})))
+    global has_external_compiler
+    if has_external_compiler is None:
+        has_external_compiler = detect_external_compiler()
+    if not has_external_compiler:
+        c = compiler()
+        return c.eval('RapydScript.msgfmt({}, {})'.format(
+            json.dumps(po_data_as_string), json.dumps({'use_fuzzy': False})))
+    cp = subprocess.run([has_external_compiler, 'msgfmt'], input=po_data_as_string.encode(), capture_output=True)
+    if cp.returncode != 0:
+        sys.stderr.write(cp.stderr)
+        raise SystemExit(cp.returncode)
+    return cp.stdout.decode().strip()
 # }}}
